ingress

package
v1.114.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 7, 2026 License: MIT Imports: 13 Imported by: 0

Documentation

Overview

Package ingress is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BuildAnnotationsFromProviders added in v1.108.0

func BuildAnnotationsFromProviders(component radixv1.RadixCommonDeployComponent, annotationProviders []AnnotationProvider) (map[string]string, error)

func BuildIngressSpecForComponent added in v1.108.0

func BuildIngressSpecForComponent(component radixv1.RadixCommonDeployComponent, hostname, tlsSecretName string) networkingv1.IngressSpec

BuildIngressSpecForComponent Builds ingress spec for a component

func BuildIngressSpecForOAuth2Component added in v1.108.0

func BuildIngressSpecForOAuth2Component(component radixv1.RadixCommonDeployComponent, hostname, tlsSecretName string) networkingv1.IngressSpec

BuildIngressSpecForOAuth2Component Builds ingress spec for a component's oauth2 service

func IsSecretRequiredForClientCertificate

func IsSecretRequiredForClientCertificate(clientCertificate *radixv1.ClientCertificate) bool

IsSecretRequiredForClientCertificate Check is Secret is required for thr ClientCertificate

func ParseClientCertificateConfiguration

func ParseClientCertificateConfiguration(clientCertificate radixv1.ClientCertificate) (certificate radixv1.ClientCertificate)

ParseClientCertificateConfiguration Parses ClientCertificate configuration

Types

type AnnotationConfiguration

type AnnotationConfiguration struct {
	Name        string
	Annotations map[string]string
}

AnnotationConfiguration Holds annotations for a single configuration

type AnnotationProvider

type AnnotationProvider interface {
	// GetAnnotations returns annotations for use on Ingress resources
	GetAnnotations(component radixv1.RadixCommonDeployComponent) (map[string]string, error)
}

func GetComponentAnnotationProvider added in v1.108.0

func GetComponentAnnotationProvider(ingressConfiguration IngressConfiguration, namespace string, oauth2DefaultConfig defaults.OAuth2Config) []AnnotationProvider

GetComponentAnnotationProvider Gets annotation providers for a component ingress

func GetOAuthProxyAnnotationProviders added in v1.114.0

func GetOAuthProxyAnnotationProviders(ingressConfiguration IngressConfiguration, namespace string) []AnnotationProvider

GetAuxOAuthAnnotationProviders Gets annotation providers for a component's OAuth service in proxy mode

func NewClientCertificateAnnotationProvider

func NewClientCertificateAnnotationProvider(certificateNamespace string) AnnotationProvider

func NewForceSslRedirectAnnotationProvider

func NewForceSslRedirectAnnotationProvider() AnnotationProvider

func NewIngressConfigurationAnnotationProvider

func NewIngressConfigurationAnnotationProvider(config IngressConfiguration) AnnotationProvider

func NewIngressPublicAllowListAnnotationProvider added in v1.61.0

func NewIngressPublicAllowListAnnotationProvider() AnnotationProvider

NewIngressPublicAllowListAnnotationProvider provides Ingress annotations for allowing only public traffic from IP addresses defined in Network.Ingress.Public.Allow field

func NewIngressPublicConfigAnnotationProvider added in v1.62.0

func NewIngressPublicConfigAnnotationProvider() AnnotationProvider

NewIngressPublicConfigAnnotationProvider provides Ingress annotations for fields in `Network.Ingress.Public`, except for `allow`

func NewOAuth2AnnotationProvider

func NewOAuth2AnnotationProvider(oauth2DefaultConfig defaults.OAuth2Config, serviceNamespace string) AnnotationProvider

func NewRedirectErrorPageAnnotationProvider added in v1.66.3

func NewRedirectErrorPageAnnotationProvider() AnnotationProvider

type IngressConfiguration

type IngressConfiguration struct {
	AnnotationConfigurations []AnnotationConfiguration `json:"configuration" yaml:"configuration"`
}

IngressConfiguration Holds all ingress annotation configurations

type MockAnnotationProvider

type MockAnnotationProvider struct {
	// contains filtered or unexported fields
}

MockAnnotationProvider is a mock of AnnotationProvider interface.

func NewMockAnnotationProvider

func NewMockAnnotationProvider(ctrl *gomock.Controller) *MockAnnotationProvider

NewMockAnnotationProvider creates a new mock instance.

func (*MockAnnotationProvider) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockAnnotationProvider) GetAnnotations

func (m *MockAnnotationProvider) GetAnnotations(component v1.RadixCommonDeployComponent) (map[string]string, error)

GetAnnotations mocks base method.

type MockAnnotationProviderMockRecorder

type MockAnnotationProviderMockRecorder struct {
	// contains filtered or unexported fields
}

MockAnnotationProviderMockRecorder is the mock recorder for MockAnnotationProvider.

func (*MockAnnotationProviderMockRecorder) GetAnnotations

func (mr *MockAnnotationProviderMockRecorder) GetAnnotations(component any) *gomock.Call

GetAnnotations indicates an expected call of GetAnnotations.

Jump to