Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ComponentImage ¶ added in v1.4.0
type ComponentImage struct {
ContainerName string
Context string
Dockerfile string
ImageName string
ImagePath string
Build bool
Scan bool
}
ComponentImage Holds info about the image associated with a component
type ComponentImageSource ¶ added in v1.8.0
type ComponentImageSource struct {
Name string
SourceFolder string
DockerfileName string
Image string
}
ComponentImageSource holds information about the container image source for a Radix component or job
type ComponentImageSourceBuilder ¶ added in v1.8.0
type ComponentImageSourceBuilder interface {
WithName(name string) ComponentImageSourceBuilder
WithSourceFolder(sourceFolder string) ComponentImageSourceBuilder
WithDockerfileName(dockerfileName string) ComponentImageSourceBuilder
WithImage(image string) ComponentImageSourceBuilder
WithSourceFunc(f SourceFunc) ComponentImageSourceBuilder
Build() ComponentImageSource
}
ComponentImageSourceBuilder handles construction of ComponentImageSource
func NewComponentImageSourceBuilder ¶ added in v1.8.0
func NewComponentImageSourceBuilder() ComponentImageSourceBuilder
NewComponentImageSourceBuilder Constructor for the ComponentImageSourceBuilder
type Definition ¶
type Definition struct {
Type v1.RadixPipelineType
Steps []StepType
}
Definition Holds pipeline definition
func GetPipelineFromName ¶
func GetPipelineFromName(name string) (*Definition, error)
GetPipelineFromName Gets pipeline from string
func GetSupportedPipelines ¶
func GetSupportedPipelines() []Definition
GetSupportedPipelines Lists supported pipelines
type SourceFunc ¶ added in v1.8.0
type SourceFunc func(*componentImageSourceBuilder)
SourceFunc defines a function that can be used as input argument to WithSourceFunc
func RadixComponentSource ¶ added in v1.8.0
func RadixComponentSource(c v1.RadixComponent) SourceFunc
RadixComponentSource returns a SourceFunc that sets properties from the RadixComponent
func RadixJobComponentSource ¶ added in v1.8.0
func RadixJobComponentSource(c v1.RadixJobComponent) SourceFunc
RadixJobComponentSource returns a SourceFunc that sets properties from the RadixJobComponent
type StepType ¶
type StepType int
StepType Enumeration of the different steps a pipeline could contain
const ( // CopyConfigToMapStep Step type to copy cloned radix config to configmap CopyConfigToMapStep StepType = iota // ApplyConfigStep Step type to apply radix config ApplyConfigStep // BuildStep Step to build the docker image BuildStep // ScanImageStep Step to scan the docker image for vulnerabilities ScanImageStep // DeployStep Step to deploy the RD DeployStep // PromoteStep Will promote a deployment from one environment to another, // or an older deployment to an active PromoteStep )
func GetStepFromName ¶
GetStepFromName Gets Step from string