random

package
v1.127.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 25, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GenerateRandomKey

func GenerateRandomKey(length int) []byte

GenerateRandomKey generates a cryptographically secure random key

func RandString

func RandString(length int) string

RandString Returns a random string of given length

func RandStringSeed

func RandStringSeed(length int, src rand.Source) string

RandStringSeed Returns a random string of given length from seed

func RandStringStrSeed

func RandStringStrSeed(length int, src string) string

RandStringStrSeed Returns a random string of given length from seed

Types

This section is empty.

Jump to